==> views_popup-6.x-2.0.tar.gz: views_popup/views-view-popup-list.tpl.php <==
<?php
// $Id: views-view-popup-list.tpl.php,v 1.1.2.1 2009/02/09 20:46:12 bwong Exp $

/**
 * Template to display a view as a table with popups.
 *
 * - $title : The title of this group of rows.  May be empty.
 * - $fields: An array of CSS IDs to use for each field id.
 * - $class: A class or classes to apply to the table, based on settings. Keyed by field ID.
 * - $popup_results : An array of results, each containing:
 *   	* - An id to give to two html elements (the popup element and the table row that instantiates the popup).
 *   	* - Content, two arrays: containing content to display in the table and content to display in the popup.
 * - $popup_headers : Contains two arrays: The headers for the table and the field names for the popup.
 */
?>
<div class="item-list">
  <?php
    function views_popup_theme_row($row_result,$type){
      $row = array();
      foreach ($row_result['content'][$type] as $field => $content)
        $row[] = "<div class='views-popup-field-$field'>"
        . ( $popup_headers[$field] ? ( "<label class='views-popup-label'>$popup_headers[$field]: </label>" ) : '' )
        . "<span class='views-popup-content'>$content</span></div>\n" ;
      return implode($row,"\n");
    }

    if ($title)
      print "<h3>$title></h3>\n";

    if ($popup_id)
      $popup_id = " id='$popup_id'";
    if ($class)
      $class=" class='$class'";
    print "<$list_type$class$popup_id>\n";

    foreach ($popup_results as $id => $row) {
      $id_num = $row['id_num'];
      print "<li rel='#views-popup-$id_num' class='views-popup-row' id='$id_num'>\n".views_popup_theme_row($row,'displayed')."</li>\n";
    }
    print "</$list_type>\n";
  ?>
</div>
<?php
  foreach ($popup_results as $id => $row) {
    $id = $row['id_num'];
    print "<div class='views-popup $popup_class' id='views-popup-$id'>\n";

    if ($popup_header)
      print "<div class='views-popup-header'>$popup_header</div>\n";

    print views_popup_theme_row($row,'popup');

    if ($popup_footer)
      print "<div class='views-popup-footer'>$popup_footer</div>\n";

    print "</div>\n";
  }
?>

==> views_popup-6.x-2.2.tar.gz: views_popup/views-view-popup-list.tpl.php <==
<?php
// $Id: views-view-popup-list.tpl.php,v 1.1.2.1.2.1 2009/04/15 18:56:42 bwong Exp $

/**
 * Template to display a view as a table with popups.
 *
 * - $title : The title of this group of rows.  May be empty.
 * - $fields: An array of CSS IDs to use for each field id.
 * - $class: A class or classes to apply to the table, based on settings. Keyed by field ID.
 * - $popup_results : An array of results, each containing:
 *   	* - An id to give to two html elements (the popup element and the table row that instantiates the popup).
 *   	* - Content, two arrays: containing content to display in the table and content to display in the popup.
 * - $popup_headers : Contains two arrays: The headers for the table and the field names for the popup.
 */
?>
<div class="item-list">
  <?php
    if ($title)
      print "<h3>$title></h3>\n";

    if ($popup_id)
      $popup_id = " id='$popup_id'";
    if ($class)
      $class=" class='$class'";
    print "<$list_type$class$popup_id>\n";

    foreach ($popup_results as $id => $row) {
      $id_num = $row['id_num'];
      print "<li rel='#views-popup-$id_num' class='views-popup-row' id='$id_num'>\n".views_popup_theme_row($row,'displayed')."</li>\n";
    }
    print "</$list_type>\n";
  ?>
</div>
<?php
  foreach ($popup_results as $id => $row) {
    $text = '';
    $id = $row['id_num'];
    $text = "<div class='views-popup $popup_class' id='views-popup-$id'>\n";

    if ($popup_header)
      $text .= "<div class='views-popup-header'>$popup_header</div>\n";

    $row_text = views_popup_theme_row($row,'popup');
    if ($row_text) {
      $text .= $row_text;
      if ($popup_footer)
        $text .= "<div class='views-popup-footer'>$popup_footer</div>\n";

      print "$text</div>\n";
    }
  }
?>
